tx_mmd: Subset active clients based on months of ARV Dispensed
Description
Generates list of clients who had 3 - 6 months of ARV dispensed during the
medication refill. You can specify the number of month(s) of ARV dispensed
by changing the month argument.
Usage
tx_mmd(
data,
months = NULL,
states = NULL,
facilities = NULL,
status = "default",
remove_duplicates = FALSE
)
Arguments
data
An NDR dataframe imported using the read_ndr().
months
The number(s) of months of interest of ARV dispensed. The default is to subset active
clients who had 3 - 6 months of ARV dispensed.
states
The name(s) of the State(s) of interest. The default utilizes all
the states in the dataframe. If specifying more than one state, combine the
states using the c() e.g. c("State 1", "State 2").
facilities
The name(s) of the facilit(ies) of interest. Default is to utilize
all the facilities contained in the dataframe. If specifying more than one
facility, combine the facilities using the c() e.g.
c("Facility 1", "Facility 2").
status
Determines how the number of active clients is calculated.
The options are to either to use the NDR current_status_28_days column
or the derived current_status column ("calculated").
remove_duplicates
Boolean argument. It specifies if duplicate patient entries in the facilities should be removed or kept
# NOT RUN {tx_mmd(ndr_example)
# subset active clients who had 2 or 4 months of ARV dispensed at last encountertx_mmd(ndr_example,
months = c(2, 4),
status = "default")
# }